@@ -1,5 +1,5 @@
 /* server-xmpp-saml20.c --- Example XMPP SASL SAML20 server.
- * Copyright (C) 2004-2024 Simon Josefsson
+ * Copyright (C) 2004-2025 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -104,7 +104,7 @@ server (Gsasl *ctx)
   gsasl_finish (session);
 }
 
-const char *samlchallenge =
+static const char *samlchallenge =
   "https://saml.example.org/SAML/Browser?SAMLRequest=PHNhbWxwOk"
   "F1dGhuUmVxdWVzdCB4bWxuczpzYW1scD0idXJuOm9hc2lzOm5hbWVzOnRjOl"
   "NBTUw6Mi4wOnByb3RvY29sIg0KICAgIElEPSJfYmVjNDI0ZmE1MTAzNDI4OT"
