@@ -1,5 +1,5 @@
 /* free.h --- Free allocated data in DIGEST-MD5 token structures.
- * Copyright (C) 2004-2022 Simon Josefsson
+ * Copyright (C) 2004-2025 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -14,12 +14,13 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GNU SASL Library; if not, write to the Free
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GNU SASL Library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
+#include <config.h>
+
 /* Get prototypes. */
 #include "free.h"
 
@@ -30,7 +31,7 @@
 #include <string.h>
 
 void
-digest_md5_free_challenge (digest_md5_challenge * c)
+digest_md5_free_challenge (digest_md5_challenge *c)
 {
   size_t i;
 
@@ -43,7 +44,7 @@ digest_md5_free_challenge (digest_md5_challenge * c)
 }
 
 void
-digest_md5_free_response (digest_md5_response * r)
+digest_md5_free_response (digest_md5_response *r)
 {
   free (r->username);
   free (r->realm);
@@ -56,7 +57,7 @@ digest_md5_free_response (digest_md5_response * r)
 }
 
 void
-digest_md5_free_finish (digest_md5_finish * f)
+digest_md5_free_finish (digest_md5_finish *f)
 {
   memset (f, 0, sizeof (*f));
 }
