@@ -1,5 +1,5 @@
 /* test-parser.c --- Self tests of DIGEST-MD5 parser & printer.
- * Copyright (C) 2004-2022 Simon Josefsson
+ * Copyright (C) 2004-2025 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -14,15 +14,12 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GNU SASL Library; if not, write to the Free
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GNU SASL Library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
