@@ -1,5 +1,5 @@
 /* validate.c --- Validate consistency of DIGEST-MD5 tokens.
- * Copyright (C) 2004-2022 Simon Josefsson
+ * Copyright (C) 2004-2025 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -14,15 +14,12 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GNU SASL Library; if not, write to the Free
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GNU SASL Library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get prototypes. */
 #include "validate.h"
@@ -31,7 +28,7 @@
 #include <string.h>
 
 int
-digest_md5_validate_challenge (digest_md5_challenge * c)
+digest_md5_validate_challenge (digest_md5_challenge *c)
 {
   /* This directive is required and MUST appear exactly once; if
      not present, or if multiple instances are present, the
@@ -50,7 +47,7 @@ digest_md5_validate_challenge (digest_md5_challenge * c)
 }
 
 int
-digest_md5_validate_response (digest_md5_response * r)
+digest_md5_validate_response (digest_md5_response *r)
 {
   /* This directive is required and MUST be present exactly
      once; otherwise, authentication fails. */
@@ -100,7 +97,7 @@ digest_md5_validate_response (digest_md5_response * r)
 }
 
 int
-digest_md5_validate_finish (digest_md5_finish * f)
+digest_md5_validate_finish (digest_md5_finish *f)
 {
   if (!*f->rspauth)
     return -1;
@@ -113,7 +110,7 @@ digest_md5_validate_finish (digest_md5_finish * f)
 }
 
 int
-digest_md5_validate (digest_md5_challenge * c, digest_md5_response * r)
+digest_md5_validate (digest_md5_challenge *c, digest_md5_response *r)
 {
   if (!c->nonce || !r->nonce)
     return -1;
