@@ -1,5 +1,5 @@
 /* gss-extra.c --- Provide GSS-API symbols when missing from library.
- * Copyright (C) 2010-2022 Simon Josefsson
+ * Copyright (C) 2010-2025 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -14,15 +14,12 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GNU SASL Library; if not, write to the Free
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GNU SASL Library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "gss-extra.h"
@@ -33,7 +30,8 @@
 /* Get malloc, free. */
 #include <stdlib.h>
 
-#ifndef HAVE_DECL_GSS_C_NT_HOSTBASED_SERVICE
+#if ! HAVE_DECL_GSS_C_NT_HOSTBASED_SERVICE
+
 /* MIT Kerberos for Windows version 3.2.2 lacks this. */
 static gss_OID_desc tmp = {
   10,
@@ -44,7 +42,7 @@ gss_OID GSS_C_NT_HOSTBASED_SERVICE = &tmp;
 
 #endif
 
-#ifndef HAVE_GSS_OID_EQUAL
+#if! HAVE_GSS_OID_EQUAL
 
 int
 gss_oid_equal (const gss_OID first_oid, const gss_OID second_oid)
@@ -57,16 +55,16 @@ gss_oid_equal (const gss_OID first_oid, const gss_OID second_oid)
 
 #endif
 
-#ifndef HAVE_GSS_INQUIRE_MECH_FOR_SASLNAME
+#if ! HAVE_GSS_INQUIRE_MECH_FOR_SASLNAME
 
 /* Provide a dummy replacement function for GSS-API libraries that
    lacks gss_inquire_mech_for_saslname.  This function only works for
    Kerberos V5.  */
 
 OM_uint32
-gss_inquire_mech_for_saslname (OM_uint32 * minor_status,
+gss_inquire_mech_for_saslname (OM_uint32 *minor_status,
 			       const gss_buffer_t sasl_mech_name,
-			       gss_OID * mech_type)
+			       gss_OID *mech_type)
 {
   static gss_OID_desc krb5oid_static = {
     9, (char *) "\x2a\x86\x48\x86\xf7\x12\x01\x02\x02"
@@ -95,10 +93,10 @@ gss_inquire_mech_for_saslname (OM_uint32 * minor_status,
  * Copyright (C) 2002 Fabio Fiorina.
  * The remaining functions below are copied from GNU GSS but re-licensed
  * to LGPLv2.1+.
- * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010  Simon Josefsson
+ * Copyright (C) 2010-2025 Simon Josefsson
  */
 
-#ifndef HAVE_GSS_ENCAPSULATE_TOKEN
+#if ! HAVE_GSS_ENCAPSULATE_TOKEN
 
 static void
 _gss_asn1_length_der (size_t len, unsigned char *ans, size_t *ans_len)
@@ -201,7 +199,7 @@ gss_encapsulate_token (const gss_buffer_t input_token,
 
 #endif /* HAVE_GSS_ENCAPSULATE_TOKEN */
 
-#ifndef HAVE_GSS_ENCAPSULATE_TOKEN
+#if ! HAVE_GSS_DECAPSULATE_TOKEN
 
 static size_t
 _gss_asn1_get_length_der (const char *der, size_t der_len, size_t *len)
@@ -335,4 +333,4 @@ gss_decapsulate_token (const gss_buffer_t input_token,
   return GSS_S_COMPLETE;
 }
 
-#endif
+#endif /* HAVE_GSS_DECAPSULATE_TOKEN */
