@@ -1,5 +1,5 @@
 /* client.c --- SASL mechanism GS2, client side.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2025 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -14,15 +14,12 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GNU SASL Library; if not, write to the Free
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GNU SASL Library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "gs2.h"
@@ -51,7 +48,7 @@ typedef struct _gsasl_gs2_client_state _gsasl_gs2_client_state;
 /* Initialize GS2 state into MECH_DATA.  Return GSASL_OK if GS2 is
    ready and initialization succeeded, or an error code. */
 int
-_gsasl_gs2_client_start (Gsasl_session * sctx, void **mech_data)
+_gsasl_gs2_client_start (Gsasl_session *sctx, void **mech_data)
 {
   _gsasl_gs2_client_state *state;
   int res;
@@ -130,7 +127,7 @@ escape_authzid (const char *str)
    import the GSS-API name, and initialize the channel binding data.
    Return GSASL_OK on success or an error code. */
 static int
-prepare (Gsasl_session * sctx, _gsasl_gs2_client_state * state)
+prepare (Gsasl_session *sctx, _gsasl_gs2_client_state *state)
 {
   const char *service = gsasl_property_get (sctx, GSASL_SERVICE);
   const char *hostname = gsasl_property_get (sctx, GSASL_HOSTNAME);
@@ -185,7 +182,7 @@ prepare (Gsasl_session * sctx, _gsasl_gs2_client_state * state)
    just copy the buffer.  Return GSASL_OK on success or an error
    code.  */
 static int
-token2output (_gsasl_gs2_client_state * state,
+token2output (_gsasl_gs2_client_state *state,
 	      const gss_buffer_t token, char **output, size_t *output_len)
 {
   OM_uint32 maj_stat, min_stat;
@@ -234,7 +231,7 @@ token2output (_gsasl_gs2_client_state * state,
    expected to be put in newly allocated OUTPUT/OUTPUT_LEN.  Return
    GSASL_NEEDS_MORE or GSASL_OK on success, or an error code.  */
 int
-_gsasl_gs2_client_step (Gsasl_session * sctx,
+_gsasl_gs2_client_step (Gsasl_session *sctx,
 			void *mech_data,
 			const char *input, size_t input_len,
 			char **output, size_t *output_len)
@@ -315,7 +312,7 @@ _gsasl_gs2_client_step (Gsasl_session * sctx,
 /* Cleanup GS2 state context, i.e., release memory associated with
    buffers in MECH_DATA state. */
 void
-_gsasl_gs2_client_finish (Gsasl_session * sctx, void *mech_data)
+_gsasl_gs2_client_finish (Gsasl_session *sctx, void *mech_data)
 {
   _gsasl_gs2_client_state *state = mech_data;
   OM_uint32 min_stat;
