@@ -1,5 +1,5 @@
 /* client.c --- SAML20 mechanism, client side.
- * Copyright (C) 2010-2024 Simon Josefsson
+ * Copyright (C) 2010-2025 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -14,9 +14,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GNU SASL Library; if not, write to the Free
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GNU SASL Library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -47,7 +46,7 @@ _gsasl_saml20_client_start (Gsasl_session *sctx _GL_UNUSED, void **mech_data)
 {
   struct saml20_client_state *state;
 
-  state = (struct saml20_client_state *) calloc (sizeof (*state), 1);
+  state = (struct saml20_client_state *) calloc (1, sizeof (*state));
   if (state == NULL)
     return GSASL_MALLOC_ERROR;
 
