@@ -1,5 +1,5 @@
 /* client.c --- SASL SCRAM client side functions.
- * Copyright (C) 2009-2022 Simon Josefsson
+ * Copyright (C) 2009-2025 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -14,15 +14,12 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GNU SASL Library; if not, write to the Free
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GNU SASL Library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 /* Get specification. */
 #include "scram.h"
@@ -54,8 +51,6 @@ struct scram_client_state
   char *cfmb;			/* client first message bare */
   char *serversignature;
   char *authmessage;
-  char *cbtlsunique;
-  size_t cbtlsuniquelen;
   struct scram_client_first cf;
   struct scram_server_first sf;
   struct scram_client_final cl;
@@ -63,14 +58,14 @@ struct scram_client_state
 };
 
 static int
-scram_start (Gsasl_session * sctx _GL_UNUSED,
+scram_start (Gsasl_session *sctx _GL_UNUSED,
 	     void **mech_data, bool plus, Gsasl_hash hash)
 {
   struct scram_client_state *state;
   char buf[CNONCE_ENTROPY_BYTES];
   int rc;
 
-  state = (struct scram_client_state *) calloc (sizeof (*state), 1);
+  state = (struct scram_client_state *) calloc (1, sizeof (*state));
   if (state == NULL)
     return GSASL_MALLOC_ERROR;
 
@@ -99,13 +94,13 @@ scram_start (Gsasl_session * sctx _GL_UNUSED,
 
 #ifdef USE_SCRAM_SHA1
 int
-_gsasl_scram_sha1_client_start (Gsasl_session * sctx, void **mech_data)
+_gsasl_scram_sha1_client_start (Gsasl_session *sctx, void **mech_data)
 {
   return scram_start (sctx, mech_data, false, GSASL_HASH_SHA1);
 }
 
 int
-_gsasl_scram_sha1_plus_client_start (Gsasl_session * sctx, void **mech_data)
+_gsasl_scram_sha1_plus_client_start (Gsasl_session *sctx, void **mech_data)
 {
   return scram_start (sctx, mech_data, true, GSASL_HASH_SHA1);
 }
@@ -113,20 +108,20 @@ _gsasl_scram_sha1_plus_client_start (Gsasl_session * sctx, void **mech_data)
 
 #ifdef USE_SCRAM_SHA256
 int
-_gsasl_scram_sha256_client_start (Gsasl_session * sctx, void **mech_data)
+_gsasl_scram_sha256_client_start (Gsasl_session *sctx, void **mech_data)
 {
   return scram_start (sctx, mech_data, false, GSASL_HASH_SHA256);
 }
 
 int
-_gsasl_scram_sha256_plus_client_start (Gsasl_session * sctx, void **mech_data)
+_gsasl_scram_sha256_plus_client_start (Gsasl_session *sctx, void **mech_data)
 {
   return scram_start (sctx, mech_data, true, GSASL_HASH_SHA256);
 }
 #endif
 
 int
-_gsasl_scram_client_step (Gsasl_session * sctx,
+_gsasl_scram_client_step (Gsasl_session *sctx,
 			  void *mech_data,
 			  const char *input, size_t input_len,
 			  char **output, size_t *output_len)
@@ -142,36 +137,13 @@ _gsasl_scram_client_step (Gsasl_session * sctx,
     {
     case 0:
       {
-	const char *p;
-
-	p = gsasl_property_get (sctx, GSASL_CB_TLS_UNIQUE);
-	if (state->plus && !p)
-	  return GSASL_NO_CB_TLS_UNIQUE;
-	if (p)
-	  {
-	    rc = gsasl_base64_from (p, strlen (p), &state->cbtlsunique,
-				    &state->cbtlsuniquelen);
-	    if (rc != GSASL_OK)
-	      return rc;
-	  }
-
-	if (state->plus)
-	  {
-	    state->cf.cbflag = 'p';
-	    state->cf.cbname = strdup ("tls-unique");
-	  }
-	else
-	  {
-	    if (state->cbtlsuniquelen > 0)
-	      state->cf.cbflag = 'y';
-	    else
-	      state->cf.cbflag = 'n';
-	  }
+	const char *p, *b64cb;
 
 	p = gsasl_property_get (sctx, GSASL_AUTHID);
 	if (!p)
 	  return GSASL_NO_AUTHID;
 
+	free (state->cf.username);
 	rc = gsasl_saslprep (p, GSASL_ALLOW_UNASSIGNED,
 			     &state->cf.username, NULL);
 	if (rc != GSASL_OK)
@@ -181,6 +153,31 @@ _gsasl_scram_client_step (Gsasl_session * sctx,
 	if (p)
 	  state->cf.authzid = strdup (p);
 
+	b64cb = gsasl_property_get (sctx, GSASL_CB_TLS_EXPORTER);
+	if (b64cb)
+	  state->cf.cbname = strdup ("tls-exporter");
+	else
+	  {
+	    b64cb = gsasl_property_get (sctx, GSASL_CB_TLS_UNIQUE);
+	    if (b64cb)
+	      state->cf.cbname = strdup ("tls-unique");
+	  }
+
+	if (state->plus)
+	  {
+	    if (!b64cb)
+	      return GSASL_NO_CB_TLS_EXPORTER;
+
+	    state->cf.cbflag = 'p';
+	  }
+	else
+	  {
+	    if (b64cb)
+	      state->cf.cbflag = 'y';
+	    else
+	      state->cf.cbflag = 'n';
+	  }
+
 	rc = scram_print_client_first (&state->cf, output);
 	if (rc == -2)
 	  return GSASL_MALLOC_ERROR;
@@ -205,21 +202,31 @@ _gsasl_scram_client_step (Gsasl_session * sctx,
 	  return GSASL_MALLOC_ERROR;
 
 	/* Prepare B64("cbind-input") for the next step. */
-	if (state->cf.cbflag == 'p')
+	if (state->plus && b64cb)
 	  {
-	    size_t len = (p - *output) + state->cbtlsuniquelen;
-	    char *cbind_input = malloc (len);
+	    size_t len;
+	    char *cbind_input;
+	    char *cb;
+	    size_t cblen;
+
+	    rc = gsasl_base64_from (b64cb, strlen (b64cb), &cb, &cblen);
+	    if (rc != GSASL_OK)
+	      return rc;
+
+	    len = (p - *output) + cblen;
+	    cbind_input = malloc (len);
 	    if (cbind_input == NULL)
 	      return GSASL_MALLOC_ERROR;
+
 	    memcpy (cbind_input, *output, p - *output);
-	    memcpy (cbind_input + (p - *output), state->cbtlsunique,
-		    state->cbtlsuniquelen);
+	    memcpy (cbind_input + (p - *output), cb, cblen);
+	    free (cb);
 	    rc = gsasl_base64_to (cbind_input, len, &state->cl.cbind, NULL);
 	    free (cbind_input);
 	  }
 	else
 	  rc = gsasl_base64_to (*output, p - *output, &state->cl.cbind, NULL);
-	if (rc != 0)
+	if (rc != GSASL_OK)
 	  return rc;
 
 	/* We are done. */
@@ -238,6 +245,7 @@ _gsasl_scram_client_step (Gsasl_session * sctx,
 		    strlen (state->cf.client_nonce)) != 0)
 	  return GSASL_AUTHENTICATION_ERROR;
 
+	free (state->cl.nonce);
 	state->cl.nonce = strdup (state->sf.nonce);
 	if (!state->cl.nonce)
 	  return GSASL_MALLOC_ERROR;
@@ -411,7 +419,7 @@ _gsasl_scram_client_step (Gsasl_session * sctx,
 }
 
 void
-_gsasl_scram_client_finish (Gsasl_session * sctx _GL_UNUSED, void *mech_data)
+_gsasl_scram_client_finish (Gsasl_session *sctx _GL_UNUSED, void *mech_data)
 {
   struct scram_client_state *state = mech_data;
 
@@ -421,7 +429,6 @@ _gsasl_scram_client_finish (Gsasl_session * sctx _GL_UNUSED, void *mech_data)
   free (state->cfmb);
   free (state->serversignature);
   free (state->authmessage);
-  free (state->cbtlsunique);
   scram_free_client_first (&state->cf);
   scram_free_server_first (&state->sf);
   scram_free_client_final (&state->cl);
