@@ -1,5 +1,5 @@
 /* register.c --- Initialize and register SASL plugin in global context.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2025 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -14,12 +14,12 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License License along with GNU SASL Library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GNU SASL Library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
+#include <config.h>
 #include "internal.h"
 
 /**
@@ -35,7 +35,7 @@
  * Since: 0.2.0
  **/
 int
-gsasl_register (Gsasl * ctx, const Gsasl_mechanism * mech)
+gsasl_register (Gsasl *ctx, const Gsasl_mechanism *mech)
 {
   Gsasl_mechanism *tmp;
 
