@@ -1,5 +1,5 @@
 /* suggest.c --- Suggest client mechanism to use, from a set of mechanisms.
- * Copyright (C) 2002-2024 Simon Josefsson
+ * Copyright (C) 2002-2025 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -14,9 +14,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License License along with GNU SASL Library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GNU SASL Library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -29,7 +28,7 @@
  * A zero-terminated character array, or string, with all ASCII
  * characters that may be used within a SASL mechanism name.
  **/
-const char *_GSASL_VALID_MECHANISM_CHARACTERS =
+static const char *_GSASL_VALID_MECHANISM_CHARACTERS =
   "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-_";
 
 /**
