@@ -1,5 +1,5 @@
 /* xfinish.c --- Finish libgsasl session.
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2025 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -14,12 +14,12 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License License along with GNU SASL Library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with GNU SASL Library; if not, see
+ * <https://www.gnu.org/licenses/>.
  *
  */
 
+#include <config.h>
 #include "internal.h"
 
 /**
@@ -30,7 +30,7 @@
  * used with other libgsasl functions after this call.
  **/
 void
-gsasl_finish (Gsasl_session * sctx)
+gsasl_finish (Gsasl_session *sctx)
 {
   if (sctx == NULL)
     return;
@@ -66,6 +66,7 @@ gsasl_finish (Gsasl_session * sctx)
   free (sctx->scram_serverkey);
   free (sctx->scram_storedkey);
   free (sctx->cb_tls_unique);
+  free (sctx->cb_tls_exporter);
   free (sctx->saml20_idp_identifier);
   free (sctx->saml20_redirect_url);
   free (sctx->openid20_redirect_url);
