@@ -1,5 +1,5 @@
 /* digest-md5.c --- Test the DIGEST-MD5 mechanism.
- * Copyright (C) 2002-2024 Simon Josefsson
+ * Copyright (C) 2002-2025 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -36,7 +36,7 @@
 #define HOSTNAME "hostname"
 #define REALM "realm"
 
-size_t i;
+static size_t i;
 
 static int
 callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
