@@ -1,5 +1,5 @@
 /* external.c --- Test the EXTERNAL mechanism.
- * Copyright (C) 2002-2024 Simon Josefsson
+ * Copyright (C) 2002-2025 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -46,7 +46,7 @@ static const struct
   /* *INDENT-ON* */
 };
 
-int i;
+static int i;
 
 static int
 callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
