@@ -1,5 +1,5 @@
 /* openid20.c --- Test the OPENID20 mechanism.
- * Copyright (C) 2010-2022 Simon Josefsson
+ * Copyright (C) 2010-2025 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -27,18 +27,20 @@
 
 #include "utils.h"
 
-const char *authzid = NULL;
-const char *sreg = NULL;
-int validation_res = GSASL_OK;
-int expect_server_res = GSASL_OK;
-int expect_client_res = GSASL_OK;
-int expect_server2_res = GSASL_MECHANISM_CALLED_TOO_MANY_TIMES;
+static const char *authzid = NULL;
+static const char *sreg = NULL;
+static int validation_res = GSASL_OK;
+static int expect_server_res = GSASL_OK;
+static int expect_client_res = GSASL_OK;
+static int expect_server2_res = GSASL_MECHANISM_CALLED_TOO_MANY_TIMES;
 
 static int
-client_callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+client_callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   switch (prop)
     {
     case GSASL_AUTHZID:
@@ -64,10 +66,12 @@ client_callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 }
 
 static int
-server_callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+server_callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   switch (prop)
     {
     case GSASL_OPENID20_REDIRECT_URL:
@@ -94,7 +98,7 @@ server_callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 }
 
 static void
-openid20 (Gsasl * c, Gsasl * s)
+openid20 (Gsasl *c, Gsasl *s)
 {
   Gsasl_session *client, *server;
   char *s1, *s2;
@@ -126,7 +130,7 @@ openid20 (Gsasl * c, Gsasl * s)
     }
 
   if (debug)
-    printf ("S: `%s' (%d) %s\n", s2 ? s2 : "", (int) strlen (s2),
+    printf ("S: `%s' (%d) %s\n", s2 ? s2 : "", s2 ? (int) strlen (s2) : 0,
 	    gsasl_strerror_name (res));
 
   /* The client should send the OpenID URL. */
@@ -140,7 +144,7 @@ openid20 (Gsasl * c, Gsasl * s)
     }
 
   if (debug)
-    printf ("C: `%s' (%d) %s\n", s1 ? s1 : "", (int) strlen (s1),
+    printf ("C: `%s' (%d) %s\n", s1 ? s1 : "", s1 ? (int) strlen (s1) : 0,
 	    gsasl_strerror_name (res));
 
   /* The server should send the redirect URL. */
@@ -154,7 +158,7 @@ openid20 (Gsasl * c, Gsasl * s)
     }
 
   if (debug)
-    printf ("S: `%s' (%d) %s\n", s2 ? s2 : "", (int) strlen (s2),
+    printf ("S: `%s' (%d) %s\n", s2 ? s2 : "", s2 ? (int) strlen (s2) : 0,
 	    gsasl_strerror_name (res));
 
   /* The client sends '='. */
@@ -168,7 +172,7 @@ openid20 (Gsasl * c, Gsasl * s)
     }
 
   if (debug)
-    printf ("C: `%s' (%d) %s\n", s1 ? s1 : "", (int) strlen (s1),
+    printf ("C: `%s' (%d) %s\n", s1 ? s1 : "", s1 ? (int) strlen (s1) : 0,
 	    gsasl_strerror_name (res));
 
   /* Now the server sends the outcome_data */
@@ -184,7 +188,7 @@ openid20 (Gsasl * c, Gsasl * s)
   if (res == GSASL_OK || res == GSASL_NEEDS_MORE)
     {
       if (debug)
-	printf ("S: `%s' (%d) %s\n", s2 ? s2 : "", (int) strlen (s2),
+	printf ("S: `%s' (%d) %s\n", s2 ? s2 : "", s2 ? (int) strlen (s2) : 0,
 		gsasl_strerror_name (res));
     }
 
@@ -201,7 +205,7 @@ openid20 (Gsasl * c, Gsasl * s)
   if (res == GSASL_OK || res == GSASL_NEEDS_MORE)
     {
       if (debug)
-	printf ("C: `%s' (%d) %s\n", s1 ? s1 : "", (int) strlen (s1),
+	printf ("C: `%s' (%d) %s\n", s1 ? s1 : "", s1 ? (int) strlen (s1) : 0,
 		gsasl_strerror_name (res));
     }
   else if (debug)
@@ -223,7 +227,7 @@ openid20 (Gsasl * c, Gsasl * s)
   if (res == GSASL_OK || res == GSASL_NEEDS_MORE)
     {
       if (debug)
-	printf ("S: `%s' (%d) %s\n", s2 ? s2 : "", (int) strlen (s2),
+	printf ("S: `%s' (%d) %s\n", s2 ? s2 : "", s2 ? (int) strlen (s2) : 0,
 		gsasl_strerror_name (res));
     }
   else if (debug)
