@@ -1,5 +1,5 @@
 /* saml20.c --- Test the SAML20 mechanism.
- * Copyright (C) 2010-2024 Simon Josefsson
+ * Copyright (C) 2010-2025 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -27,7 +27,7 @@
 
 #include "utils.h"
 
-const char *samlchallenge =
+static const char *samlchallenge =
   "https://saml.example.org/SAML/Browser?SAMLRequest=PHNhbWxwOk"
   "F1dGhuUmVxdWVzdCB4bWxuczpzYW1scD0idXJuOm9hc2lzOm5hbWVzOnRjOl"
   "NBTUw6Mi4wOnByb3RvY29sIg0KICAgIElEPSJfYmVjNDI0ZmE1MTAzNDI4OT"
@@ -185,7 +185,7 @@ doit (void)
     }
 
   if (debug)
-    printf ("C: `%s' (%d)\n", s1 ? s1 : "", (int) strlen (s1));
+    printf ("C: `%s' (%d)\n", s1 ? s1 : "", s1 ? (int) strlen (s1) : 0);
 
   res = gsasl_step64 (server, s1, &s2);
   gsasl_free (s1);
@@ -196,7 +196,7 @@ doit (void)
     }
 
   if (debug)
-    printf ("S: `%s' (%d)\n", s2 ? s2 : "", (int) strlen (s2));
+    printf ("S: `%s' (%d)\n", s2 ? s2 : "", s2 ? (int) strlen (s2) : 0);
 
   res = gsasl_step64 (client, s2, &s1);
   gsasl_free (s2);
@@ -207,7 +207,7 @@ doit (void)
     }
 
   if (debug)
-    printf ("C: `%s' (%d)\n", s1 ? s1 : "", (int) strlen (s1));
+    printf ("C: `%s' (%d)\n", s1 ? s1 : "", s1 ? (int) strlen (s1) : 0);
 
   res = gsasl_step64 (server, s1, &s2);
   gsasl_free (s1);
@@ -218,7 +218,7 @@ doit (void)
     }
 
   if (debug)
-    printf ("S: `%s' (%d)\n", s2 ? s2 : "", (int) strlen (s2));
+    printf ("S: `%s' (%d)\n", s2 ? s2 : "", s2 ? (int) strlen (s2) : 0);
 
   gsasl_free (s2);
 
