@@ -1,5 +1,5 @@
 /* scram.c --- Test the SCRAM mechanism.
- * Copyright (C) 2009-2022 Simon Josefsson
+ * Copyright (C) 2009-2025 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -44,13 +42,15 @@ static const char *AUTHZID[N_AUTHZID] = {
   "jas", "BAB,ABA", ",=,=", "="
 };
 
-int i;
+static int i;
 
 static int
-callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+callback (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   int rc = GSASL_NO_CALLBACK;
 
+  (void) ctx;
+
   /* Get user info from user. */
 
   switch (prop)
@@ -100,6 +100,7 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       break;
 
     case GSASL_CB_TLS_UNIQUE:
+    case GSASL_CB_TLS_EXPORTER:
       break;
 
     default:
