@@ -1,5 +1,5 @@
 /* startcb.c --- Verify that mechanism start() do not invoke callbacks.
- * Copyright (C) 2020-2022 Simon Josefsson
+ * Copyright (C) 2020-2025 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -18,9 +18,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
+#include <config.h>
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -48,10 +46,12 @@
 static bool incb;
 
 static int
-cb (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
+cb (Gsasl *ctx, Gsasl_session *sctx, Gsasl_property prop)
 {
   const char *mn = gsasl_mechanism_name (sctx);
 
+  (void) ctx;
+
   printf ("Callback %s for property %u\n", mn, prop);
 
   incb = true;
